Skip to contents

Like create_chl_trg_visualization(), but the x-axis is left as the raw character row names (no coercion to numeric).

Usage

create_chl_trg_visualization_pvzp(data_matrix, columns)

Arguments

data_matrix

A named matrix where row names act as the x-axis.

columns

Character or numeric vector – which columns to plot.

Value

A plotly htmlwidget.