Computes one row of development factors per requested length ("full" or
an integer giving how many of the most recent rows to use). Factors are
aggregated using the standard volume-weighted formula
sum(cum[, j]) / sum(cum[, j - 1]).
Computes one row of development factors per requested length ("full" or
an integer giving how many of the most recent rows to use). Factors are
aggregated using the standard volume-weighted formula
sum(cum[, j]) / sum(cum[, j - 1]).