Cumulative product of chain-ladder factors (ultimate development)
Source:R/chain-ladder.R
create_product_coefs.RdGiven a one-row data frame of development factors as returned by
create_chl_coefs(), computes the cumulative product from each
development period to the tail.
Arguments
- chl_coefs
A one-row data frame whose first column is a label and whose other columns hold development factors. (As returned by
create_chl_coefs().)- name
Character – label for the resulting row.